Package: datamedios
Type: Package
Title: Scraping Chilean Media
Version: 1.2.3
Authors@R: c(
  person(given = "Exequiel", family = "Trujillo", email = "exequiel.trujillo@ug.uchile.cl", role = c("aut", "cre", "cph", "fnd")),
  person(given = "Ismael", family = "Aguayo", email = "ismael.aguayo@ug.uchile.cl", role = c("aut", "fnd")),
  person(given = "Klaus", family = "Lehmann", email = "klehmann@fen.uchile.cl", role = c("aut", "fnd")),
  person(given = "Matias", family = "Gallardo", email = "matias.gallardo.v@ug.uchile.cl", role = c("ctb"))
  )
Maintainer: Exequiel Trujillo <exequiel.trujillo@ug.uchile.cl>
Description: A system for extracting news from Chilean media,
  specifically through Web Scapping from Chilean media. The package allows for news searches using search phrases and date filters,
  and returns the results in a structured format, ready for analysis.
  Additionally, it includes functions to clean the extracted data, visualize it, and
  store it in databases. All of this can be done automatically, facilitating the collection and analysis of relevant
  information from Chilean media.
License: MIT + file LICENSE
Encoding: UTF-8
Language: es-ES
Depends: R (>= 4.1)
Suggests: rcmdcheck
Imports: dplyr, httr, magrittr, jsonlite, utils, rlang, wordcloud2,
        tidytext, lubridate, rvest, stringr, xml2, purrr, DT, ggplot2,
        plotly, parallel, pbapply
URL: https://socialtec-cl.github.io/datamedios/,
        https://github.com/Socialtec-cl/datamedios
BugReports: https://github.com/Socialtec-cl/datamedios/issues
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-04-27 00:02:20 UTC; Compu
Author: Exequiel Trujillo [aut, cre, cph, fnd],
  Ismael Aguayo [aut, fnd],
  Klaus Lehmann [aut, fnd],
  Matias Gallardo [ctb]
Repository: CRAN
Date/Publication: 2026-04-27 02:10:02 UTC
Built: R 4.6.0; ; 2026-04-27 05:19:52 UTC; unix
