# Generated by roxygen2: do not edit by hand

export("%>%")
export(agregar_datos_unicos)
export(extraccion_parrafos)
export(extraer_noticias_fecha)
export(extraer_noticias_fecha_bbcl)
export(extraer_noticias_fecha_ciper)
export(extraer_noticias_fecha_emol)
export(extraer_noticias_max_res)
export(extraer_noticias_max_res_bbcl)
export(extraer_noticias_max_res_ciper)
export(extraer_noticias_max_res_emol)
export(grafico_comparacion_medios)
export(grafico_notas_fecha)
export(grafico_notas_por_mes)
export(init_req_bbcl)
export(init_req_emol)
export(iteracion_emol)
export(limpieza_notas)
export(parserFuentes)
export(tabla_frecuencia_palabras)
export(word_cloud)
import(dplyr)
import(pbapply)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(stats,setNames)
importFrom(utils,URLencode)
