#' @importFrom utils URLencode
#' @importFrom rlang .data
#' @export
utils::globalVariables(c(
  "contenido", "fecha", "cantidad", "word",
  "contenido_limpio", "n", "ID", "_id", "_source.autor",
  "_source.bajada", "_source.imagen", "_source.permalink",
  "_source.seccion", "_source.subSeccion", "_source.tablas.tablaMedios",
  "_source.temas", "_source.texto", "_source.titulo", "autor", "medio",
  "resumen", "temas", "titulo", "url_imagen", "fecha_grupo", "fecha_texto"
))
