% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-emol-helpers.R
\name{helper_extraer_url_imagen}
\alias{helper_extraer_url_imagen}
\title{Helper para extraer la URL de la imagen de datos de Emol}
\usage{
helper_extraer_url_imagen(source_tablas_medios, source_imagen, fuente_actual)
}
\arguments{
\item{source_tablas_medios}{El contenido de la columna `_source.tablas.tablaMedios`
de la fila actual. Puede ser un dataframe, lista, o NULL.}

\item{source_imagen}{El contenido de la columna `_source.imagen` de la fila actual.
Puede ser un string, lista, o NULL.}

\item{fuente_actual}{Un string que indica la fuente de la noticia (e.g., "emol",
"guioteca", "mediosregionales").}
}
\value{
Un string (character) con la URL de la imagen, o `NA_character_` si
  no se puede extraer una URL valida o si ocurre un error.
}
\description{
Esta funcion interna procesa las columnas relevantes de una fila de datos
de Emol para extraer la URL de la imagen principal de la noticia.
Prioriza `_source.tablas.tablaMedios` para fuentes "emol" y "mediosregionales",
y recurre a `_source.imagen` para otras o si la primera falla.
Maneja diferentes estructuras de datos (dataframes, listas, valores atomicos).
}
\keyword{internal}
