% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-emol-helpers.R
\name{helper_extraer_resumen}
\alias{helper_extraer_resumen}
\title{Helper para extraer el resumen (bajada) de datos de Emol}
\usage{
helper_extraer_resumen(bajada_val)
}
\arguments{
\item{bajada_val}{El contenido de la columna `_source.bajada` de la fila actual.}
}
\value{
Un string (character) con el texto del resumen, o `NA_character_`
  si no se puede extraer o si ocurre un error.
}
\description{
Esta funcion interna procesa la columna `_source.bajada` de una fila
de datos de Emol para extraer el texto del resumen.
Maneja casos donde `_source.bajada` puede ser NULL, un dataframe,
una lista, o un valor atomico.
}
\keyword{internal}
